==> Paws-0.39.tar.gz: Paws-0.39/lib/Paws/SecurityHub/DisassociateMembers.pm <==

package Paws::SecurityHub::DisassociateMembers;
  use Moose;
  has AccountIds => (is => 'ro', isa => 'ArrayRef[Str|Undef]');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DisassociateMembers');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/members/disassociate');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'POST');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::SecurityHub::DisassociateMembersResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::SecurityHub::DisassociateMembers - Arguments for method DisassociateMembers on L<Paws::SecurityHub>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DisassociateMembers on the
L<AWS SecurityHub|Paws::SecurityHub> service. Use the attributes of this class
as arguments to method DisassociateMembers.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DisassociateMembers.

=head1 SYNOPSIS

    my $securityhub = Paws->service('SecurityHub');
    my $DisassociateMembersResponse = $securityhub->DisassociateMembers(
      AccountIds => [ 'MyNonEmptyString', ... ],    # OPTIONAL
    );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/securityhub/DisassociateMembers>

=head1 ATTRIBUTES


=head2 AccountIds => ArrayRef[Str|Undef]

The account IDs of the member accounts that you want to disassociate
from the master account.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DisassociateMembers in L<Paws::SecurityHub>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.43.tar.gz: Paws-0.43/lib/Paws/SecurityHub/DisassociateMembers.pm <==

package Paws::SecurityHub::DisassociateMembers;
  use Moose;
  has AccountIds => (is => 'ro', isa => 'ArrayRef[Str|Undef]');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DisassociateMembers');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/members/disassociate');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'POST');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::SecurityHub::DisassociateMembersResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::SecurityHub::DisassociateMembers - Arguments for method DisassociateMembers on L<Paws::SecurityHub>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DisassociateMembers on the
L<AWS SecurityHub|Paws::SecurityHub> service. Use the attributes of this class
as arguments to method DisassociateMembers.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DisassociateMembers.

=head1 SYNOPSIS

    my $securityhub = Paws->service('SecurityHub');
    my $DisassociateMembersResponse = $securityhub->DisassociateMembers(
      AccountIds => [ 'MyNonEmptyString', ... ],    # OPTIONAL
    );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/securityhub/DisassociateMembers>

=head1 ATTRIBUTES


=head2 AccountIds => ArrayRef[Str|Undef]

The account IDs of the member accounts to disassociate from the master
account.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DisassociateMembers in L<Paws::SecurityHub>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
